@@ -178,7 +178,7 @@ class Resource:
             and url_parts[0] == "api"
             and url_parts[1] not in basic_endpoints
         ):
-            raise UnsupportedResourceError(f"{url_parts[1].title()} are part of Datapane Enterprise.")
+            raise UnsupportedResourceError(f"{url_parts[1].title()} are part of Datapane Cloud.")
 
     def post(self, params: t.Dict = None, **data: JSON) -> JSON:
         params = params or dict()
