@@ -20,11 +20,12 @@ from dominate.dom_tag import dom_tag
 from glom import glom
 from lxml import etree
 from lxml.builder import ElementMaker
-from micawber import ProviderException, bootstrap_basic, cache
+from lxml.etree import Element
 from pandas.io.formats.style import Styler
 
 from datapane.client import DPError
 from datapane.common import PKL_MIMETYPE, NPath, guess_type
+from datapane.common.report import conv_attribs, get_embed_url, is_valid_id
 
 from ..common import DPTmpFile
 from ..dp_object import save_df
@@ -47,11 +48,10 @@ __all__ = [
     "Code",
     "HTML",
     "File",
+    "Formula",
 ]
 
 __pdoc__ = {
-    "BaseElement.id": False,
-    "DataBlock.id": False,
     "File.caption": False,
     "File.file": False,
     "Plot.file": False,
@@ -72,9 +72,10 @@ class BuilderState:
     id_count: t.Iterator[int] = dc.field(default_factory=lambda: itertools.count(start=1))
 
     def add_element(self, block: "BaseElement", e: etree.Element, f: t.Optional[Path] = None) -> "BuilderState":
-        # set fresh id's if not set
-        _id = str(block.id) if block.id else f"block-{next(self.id_count)}"
-        e.set("id", _id)
+        if not isinstance(block, Page):
+            # set fresh name if not set
+            _name = block.name if block.name else f"{block._block_name}-{next(self.id_count)}"
+            e.set("name", _name)
 
         self.elements.append(e)
         if f and not self.embedded:
@@ -85,18 +86,6 @@ class BuilderState:
         return self
 
 
-def _conv_attrib(v: t.Any) -> t.Optional[str]:
-    """
-    Convert a value to a str for use as an ElementBuilder attribute
-    - also handles None to a string for optional field values
-    """
-    # TODO - use a proper serialisation framework here / lxml features
-    if v is None:
-        return v
-    v1 = str(v)
-    return v1.lower() if isinstance(v, bool) else v1
-
-
 class BaseElement(ABC):
     """Base Block class - subclassed by all Block types
 
@@ -105,23 +94,30 @@ class BaseElement(ABC):
 
     _attributes: t.Dict[str, str]
     _tag: str
-    id: t.Optional[str] = None
+    _block_name: str
+    name: t.Optional[str] = None
 
-    def __init__(self, id: str = None, **kwargs):
+    def __init__(self, name: str = None, **kwargs):
         """
         Args:
-            id: A unique id to reference the block, used when querying blocks via XPath to aid embedding
+            name: A unique name to reference the block, used when referencing blocks via the report editor and when embedding
         """
-        self.id = id
-        self._attributes = {}
+        self._block_name = self._tag.lower()
+        self._attributes = dict()
         self._add_attributes(**kwargs)
 
+        if "caption" in kwargs:
+            if len(kwargs["caption"]) > 512:
+                raise DPError("Caption must be less than 512 characters")
+
+        if name:
+            # validate name
+            if not is_valid_id(name):
+                raise DPError(f"Invalid name '{name}' for block")
+            self.name = name
+
     def _add_attributes(self, **kwargs):
-        # convert attributes, dropping None values
-        # TODO - uncomment when 3.8+ only
-        # self.attributes = {str(k): v1 for (k, v) in kwargs.items() if (v1 := _conv_attrib(v)) is not None}
-        new_attributes = {str(k): _conv_attrib(v) for (k, v) in kwargs.items() if _conv_attrib(v) is not None}
-        self._attributes.update(new_attributes)
+        self._attributes.update(conv_attribs(**kwargs))
 
     @abstractmethod
     def _to_xml(self, s: BuilderState) -> BuilderState:
@@ -199,20 +195,17 @@ class Page(LayoutBlock):
     # NOTE - technically a higher-level layoutblock but we keep here to maximise reuse
     _tag = "Page"
 
-    def __init__(
-        self, *arg_blocks: BlockOrPrimitive, blocks: t.List[BlockOrPrimitive] = None, id: str = None, label: str = None
-    ):
+    def __init__(self, *arg_blocks: BlockOrPrimitive, blocks: t.List[BlockOrPrimitive] = None, title: str = None):
         """
         Args:
-            *arg_blocks: Page to add to report
+            *arg_blocks: Blocks to add to Page
             blocks: Allows providing the report blocks as a single list
-            id: A unique id for the blocks to aid querying (optional)
-            label: A label used when displaying the block (optional)
+            title: The page title (optional)
 
         ..tip:: Page can be passed using either arg parameters or the `blocks` kwarg, e.g.
           `dp.Page(group, select)` or `dp.Group(blocks=[group, select])`
         """
-        super().__init__(*arg_blocks, blocks=blocks, id=id, label=label)
+        super().__init__(*arg_blocks, blocks=blocks, label=title)
         self._wrap_blocks()
 
     def _wrap_blocks(self) -> None:
@@ -243,7 +236,7 @@ class Select(LayoutBlock):
         *arg_blocks: BlockOrPrimitive,
         blocks: t.List[BlockOrPrimitive] = None,
         type: t.Optional[SelectType] = None,
-        id: str = None,
+        name: str = None,
         label: str = None,
     ):
         """
@@ -251,14 +244,14 @@ class Select(LayoutBlock):
             *arg_blocks: Page to add to report
             blocks: Allows providing the report blocks as a single list
             type: An instance of SelectType that indicates if the select should use tabs or a dropdown
-            id: A unique id for the blocks to aid querying (optional)
+            name: A unique id for the blocks to aid querying (optional)
             label: A label used when displaying the block (optional)
 
         ..tip:: Select can be passed using either arg parameters or the `blocks` kwarg, e.g.
           `dp.Select(table, plot, type=dp.SelectType.TABS)` or `dp.Group(blocks=[table, plot])`
         """
         _type = glom(type, "value", default=None)
-        super().__init__(*arg_blocks, blocks=blocks, id=id, label=label, type=_type)
+        super().__init__(*arg_blocks, blocks=blocks, name=name, label=label, type=_type)
         if len(self.blocks) < 2:
             raise DPError("Can't create Select with less than 2 objects")
 
@@ -280,7 +273,7 @@ class Group(LayoutBlock):
         self,
         *arg_blocks: BlockOrPrimitive,
         blocks: t.List[BlockOrPrimitive] = None,
-        id: str = None,
+        name: str = None,
         label: str = None,
         rows: int = 0,
         columns: int = 1,
@@ -289,7 +282,7 @@ class Group(LayoutBlock):
         Args:
             *arg_blocks: Group to add to report
             blocks: Allows providing the report blocks as a single list
-            id: A unique id for the blocks to aid querying (optional)
+            name: A unique id for the blocks to aid querying (optional)
             label: A label used when displaying the block (optional)
             rows: Display the contained blocks, e.g. Plots, using _n_ rows (set to 0 to autofill)
             columns: Display the contained blocks, e.g. Plots, using _n_ columns (set to 0 to autofill)
@@ -297,7 +290,7 @@ class Group(LayoutBlock):
         .. tip:: Group can be passed using either arg parameters or the `blocks` kwarg, e.g.
           `dp.Group(plot, table, columns=2)` or `dp.Group(blocks=[plot, table], columns=2)`
         """
-        super().__init__(*arg_blocks, blocks=blocks, id=id, label=label)
+        super().__init__(*arg_blocks, blocks=blocks, name=name, label=label)
 
         # set row/column handling
         if rows == 1 and columns == 1:
@@ -349,14 +342,14 @@ class Text(EmbeddedTextBlock):
 
     _tag = "Text"
 
-    def __init__(self, text: str = None, file: NPath = None, id: str = None, label: str = None):
+    def __init__(self, text: str = None, file: NPath = None, name: str = None, label: str = None):
         """
         Args:te
             text: The markdown formatted text, use triple-quotes, (`\"\"\"# My Title\"\"\"`) to create multi-line markdown text
             file: Path to a file containing markdown text
-            id: A unique id for the block to aid querying (optional)
+            name: A unique name for the block to reference when adding text or embedding (optional)
         """
-        super().__init__(id=id, label=label)
+        super().__init__(name=name, label=label)
 
         if text:
             text = text.strip()
@@ -410,15 +403,16 @@ class Code(EmbeddedTextBlock):
 
     _tag = "Code"
 
-    def __init__(self, code: str, language: str = "python", id: str = None, label: str = None):
+    def __init__(self, code: str, language: str = "python", caption: str = None, name: str = None, label: str = None):
         """
         Args:
             code: The source code
             language: The language of the code, most common languages are supported (optional - defaults to Python)
-            id: A unique id for the block to aid querying (optional)
+            caption: A caption to display below the Code (optional)
+            name: A unique name for the block to reference when adding text or embedding (optional)
             label: A label used when displaying the block (optional)
         """
-        super().__init__(id=id, label=label, language=language)
+        super().__init__(language=language, caption=caption, name=name, label=label)
         self.content = code
 
 
@@ -429,50 +423,58 @@ class HTML(EmbeddedTextBlock):
 
     _tag = "HTML"
 
-    def __init__(self, html: t.Union[str, dom_tag], id: str = None, label: str = None):
+    def __init__(self, html: t.Union[str, dom_tag], name: str = None, label: str = None):
         """
         Args:
             html: The HTML fragment to embed - can be a string or a [dominate](https://github.com/Knio/dominate/) tag
-            id: A unique id for the block to aid querying (optional)
+            name: A unique name for the block to reference when adding text or embedding (optional)
             label: A label used when displaying the block (optional)
         """
-        super().__init__(id=id, label=label)
+        super().__init__(name=name, label=label)
         self.content = str(html)
 
 
+class Formula(EmbeddedTextBlock):
+    """
+    Formula blocks can be used to embed LaTeX in a report.
+    """
+
+    _tag = "Formula"
+
+    def __init__(self, formula: str, caption: str = None, name: str = None, label: str = None):
+        """
+        Args:
+            formula: The formula to embed, using LaTeX format
+            caption: A caption to display below the Formula (optional)
+            name: A unique name for the block to reference when adding text or embedding (optional)
+            label: A label used when displaying the block (optional)"""
+        super().__init__(caption=caption, name=name, label=label)
+        self.content = formula
+
+
 class Embed(EmbeddedTextBlock):
     """
     Embed blocks allow HTML from OEmbed providers (e.g. Youtube, Twitter, Vimeo) to be embedded in a report.
     """
 
     _tag = "Embed"
-    providers = bootstrap_basic(cache=cache.Cache())
 
-    def __init__(self, url: str, width: int = 640, height: int = 480, id: str = None, label: str = None):
+    def __init__(self, url: str, width: int = 960, height: int = 540, name: str = None, label: str = None):
         """
         Args:
             url: The URL of the resource to be embedded
             width: The width of the embedded object (optional)
             height: The height of the embedded object (optional)
-            id: A unique id for the block to aid querying (optional)
+            name: A unique name for the block to reference when adding text or embedding (optional)
             label: A label used when displaying the block (optional)
         """
 
-        try:
-            result = self.providers.request(url, maxwidth=width, maxheight=height)
-        except ProviderException:
-            raise DPError(f"No embed provider found for URL '{url}'")
-        super().__init__(
-            id=id,
-            label=label,
-            url=url,
-            title=result.get("title", "Title"),
-            provider_name=result.get("provider_name", "Embedding"),
-        )
+        result = get_embed_url(url, width=width, height=height)
+        super().__init__(name=name, label=label, url=url, title=result.title, provider_name=result.provider)
 
         # if "html" not in result:
         #     raise DPError(f"Can't embed result from provider for URL '{url}'")
-        self.content = result["html"]
+        self.content = result.html
 
 
 NumberValue = t.Union[str, int, float]
@@ -493,7 +495,7 @@ class BigNumber(DataBlock):
         prev_value: t.Optional[NumberValue] = None,
         is_positive_intent: t.Optional[bool] = None,
         is_upward_change: t.Optional[bool] = None,
-        id: str = None,
+        name: str = None,
         label: str = None,
     ):
         """
@@ -504,7 +506,7 @@ class BigNumber(DataBlock):
             change: The amount changed between the value and previous value (optional)
             is_positive_intent: Displays the change on a green background if `True`, and red otherwise. Follows `is_upward_change` if not set (optional)
             is_upward_change: Whether the change is upward or downward (required when `change` is set)
-            id: A unique id for the block to aid querying (optional)
+            name: A unique name for the block to reference when adding text or embedding (optional)
             label: A label used when displaying the block (optional)
         """
         if change:
@@ -520,9 +522,9 @@ class BigNumber(DataBlock):
             value=value,
             change=change,
             prev_value=prev_value,
-            is_positive_intent=is_positive_intent,
-            is_upward_change=is_upward_change,
-            id=id,
+            is_positive_intent=bool(is_positive_intent),
+            is_upward_change=bool(is_upward_change),
+            name=name,
             label=label,
         )
 
@@ -538,9 +540,9 @@ class AssetBlock(DataBlock):
     file: Path = None
     caption: t.Optional[str] = None
 
-    def __init__(self, file: Path, caption: str = None, id: str = None, label: str = None, **kwargs):
+    def __init__(self, file: Path, caption: str = None, name: str = None, label: str = None, **kwargs):
         # storing objects for delayed upload
-        super().__init__(id=id, label=label, **kwargs)
+        super().__init__(name=name, label=label, **kwargs)
         self.file = Path(file)
         self.caption = caption or ""
 
@@ -549,6 +551,7 @@ class AssetBlock(DataBlock):
 
         content_type = guess_type(self.file)
         file_size = str(self.file.stat().st_size)
+        e: Element
 
         if s.embedded:
             # load the file and embed into a data-uri
@@ -570,7 +573,7 @@ class AssetBlock(DataBlock):
             )
 
         if self.caption:
-            e.append(E.Caption(self.caption))
+            e.set("caption", self.caption)
         return s.add_element(self, e, self.file)
 
     def _save_obj(cls, data: t.Any, as_json: bool) -> DPTmpFile:
@@ -594,9 +597,8 @@ class File(AssetBlock):
         data: t.Optional[t.Any] = None,
         file: t.Optional[NPath] = None,
         is_json: bool = False,
-        can_download: bool = True,
-        name: t.Optional[str] = None,
-        id: str = None,
+        filename: t.Optional[str] = None,
+        name: str = None,
         label: str = None,
     ):
         """
@@ -604,9 +606,8 @@ class File(AssetBlock):
             data: A python object to attach to the report (e.g. a dictionary)
             file: Path to a file to attach to the report (e.g. a JPEG image)
             is_json: If `True`, treat the `data` as JSON data already
-            can_download: Allow users to download the file when viewing the report
-            name: Name to be used when downloading the file
-            id: A unique id for the block to aid querying (optional)
+            filename: Name to be used when downloading the file
+            name: A unique name for the block to reference when adding text or embedding (optional)
             label: A label used when displaying the block (optional)
 
         ..note:: either `data` or `file` must be provided
@@ -617,7 +618,7 @@ class File(AssetBlock):
             out_fn = self._save_obj(data, as_json=is_json)
             file = out_fn.file
 
-        super().__init__(file=file, name=name or file.name, can_download=can_download, id=id, label=label)
+        super().__init__(file=file, filename=filename or file.name, name=name, label=label)
 
 
 class Plot(AssetBlock):
@@ -629,14 +630,14 @@ class Plot(AssetBlock):
     _tag = "Plot"
 
     def __init__(
-        self, data: t.Any, caption: t.Optional[str] = None, responsive: bool = True, id: str = None, label: str = None
+        self, data: t.Any, caption: t.Optional[str] = None, responsive: bool = True, name: str = None, label: str = None
     ):
         """
         Args:
             data: The `plot` object to attach
             caption: A caption to display below the plot (optional)
             responsive: Whether the plot should automatically be resized to fit, set to False if your plot looks odd (optional, default: True)
-            id: A unique id for the block to aid querying (optional)
+            name: A unique name for the block to reference when adding text or embedding (optional)
             label: A label used when displaying the block (optional)
         """
         out_fn = self._save_obj(data, as_json=False)
@@ -644,7 +645,7 @@ class Plot(AssetBlock):
             raise DPError("Can't embed object as a plot")
 
         super().__init__(
-            file=out_fn.file, caption=caption, width=640, height=480, id=id, label=label, responsive=responsive
+            file=out_fn.file, caption=caption, width=640, height=480, name=name, label=label, responsive=responsive
         )
 
 
@@ -660,17 +661,17 @@ class Table(AssetBlock):
     _tag = "Table"
 
     def __init__(
-        self, data: t.Union[pd.DataFrame, Styler], caption: t.Optional[str] = None, id: str = None, label: str = None
+        self, data: t.Union[pd.DataFrame, Styler], caption: t.Optional[str] = None, name: str = None, label: str = None
     ):
         """
         Args:
             data: The pandas `Styler` instance or dataframe to generate the table from
             caption: A caption to display below the table (optional)
-            id: A unique id for the block to aid querying (optional)
+            name: A unique name for the block to reference when adding text or embedding (optional)
             label: A label used when displaying the block (optional)
         """
         out_fn = self._save_obj(data, as_json=False)
-        super().__init__(file=out_fn.file, caption=caption, id=id, label=label)
+        super().__init__(file=out_fn.file, caption=caption, name=name, label=label)
 
 
 class DataTable(AssetBlock):
@@ -689,16 +690,16 @@ class DataTable(AssetBlock):
         self,
         df: pd.DataFrame,
         caption: t.Optional[str] = None,
-        id: str = None,
+        name: str = None,
         label: str = None,
     ):
         """
         Args:
             df: The pandas dataframe to attach to the report
             caption: A caption to display below the plot (optional)
-            id: A unique id for the block to aid querying (optional)
+            name: A unique name for the block to reference when adding text or embedding (optional)
             label: A label used when displaying the block (optional)
         """
         fn = save_df(df)
         (rows, columns) = df.shape
-        super().__init__(file=fn.file, caption=caption, rows=rows, columns=columns, id=id, label=label)
+        super().__init__(file=fn.file, caption=caption, rows=rows, columns=columns, name=name, label=label)
