@@ -164,11 +164,10 @@ def blob():
 @click.argument("name")
 @click.argument("file", type=click.Path(exists=True))
 @click.option("--group")
-@click.option("--visibility", type=click.Choice(["PUBLIC", "PRIVATE"]))
-def upload(file: str, name: str, group: str, visibility: str):
+def upload(file: str, name: str, group: str):
     """Upload a csv or Excel file as a Datapane Blob"""
     log.info(f"Uploading {file}")
-    r = api.Blob.upload_file(file, name=name, group=group, visibility=visibility)
+    r = api.Blob.upload_file(file, name=name, group=group)
     success_msg(f"Uploaded {click.format_filename(file)} to {r.url}")
 
 
@@ -245,13 +244,12 @@ def script_init(name: str):
 @click.option("--config", type=click.Path(exists=True))
 @click.option("--script", type=click.Path(exists=True))
 @click.option("--name")
-@click.option("--visibility", type=click.Choice(["PUBLIC", "PRIVATE"]))
 @click.option("--group")
-def deploy(name: Optional[str], script: Optional[str], config: Optional[str], visibility: str, group: str):
+def deploy(name: Optional[str], script: Optional[str], config: Optional[str], group: str):
     """Package and deploy a Python script or Jupyter notebook as a Datapane Script bundle"""
     script = script and Path(script)
     config = config and Path(config)
-    init_kwargs = dict(visibility=visibility, name=name, script=script, config_file=config, group=group)
+    init_kwargs = dict(name=name, script=script, config_file=config, group=group)
     kwargs = {k: v for k, v in init_kwargs.items() if v is not None}
 
     # if not (script or config or sc.DatapaneCfg.exists()):
@@ -418,20 +416,15 @@ def variable():
 @click.argument("name", required=True)
 @click.argument("value", required=True)
 @click.option("--group")
-@click.option("--visibility", type=click.Choice(["PUBLIC", "PRIVATE"]))
-def create(name: str, value: str, group: str, visibility: str):
+def create(name: str, value: str, group: str):
     """
     Create a variable
 
     NAME: name of variable
     VALUE: value of variable
     group: Group name (optional and only applicable for organistations)
-
-    --visibility:
-    PUBLIC: visible to everyone,
-    PRIVATE: only visible to you
     """
-    api.Variable.create(name, value, group, visibility)
+    api.Variable.create(name, value, group)
     success_msg(f"Created variable: {name}")
 
 
@@ -452,7 +445,7 @@ def get(name, owner, show):
         print(str(res.value).strip())
     else:
         print_table(
-            [{"name": name, "value": res.value, "visibility": res.visibility}],
+            [{"name": res.name, "value": res.value}],
             "Variable",
         )
 
